# Chatbot Connectors

![Python](https://img.shields.io/badge/python-3.8+-blue.svg)
![PyPI](https://img.shields.io/pypi/v/chatbot-connectors)
![License](https://img.shields.io/badge/license-MIT-green.svg)

A Python library for connecting to various chatbot APIs with a unified interface.
